@@ -1,22 +1,6 @@
 /* This file is part of Spectacle, the KDE screenshot utility
- * Copyright 2019 David Redondo <kde@david-redondo.de>
- * Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
+ * SPDX-FileCopyrightText: 2019 David Redondo <kde@david-redondo.de>
+ * SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
@@ -455,11 +439,7 @@ bool ExportManager::isFileExists(const QUrl &url) const
     if (!(url.isValid())) {
         return false;
     }
-#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
-    KIO::StatJob * existsJob = KIO::stat(url, KIO::StatJob::DestinationSide, 0);
-#else
-    KIO::StatJob * existsJob = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatNoDetails);
-#endif
+    KIO::StatJob * existsJob = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatNoDetails, KIO::HideProgressInfo);
 
     existsJob->exec();
 
