@@ -1,21 +1,6 @@
 /* This file is part of Spectacle, the KDE screenshot utility
- * Copyright (C) 2019 Boudhayan Gupta <bgupta@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
+ * SPDX-FileCopyrightText: 2019 Boudhayan Gupta <bgupta@kde.org>
+
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
@@ -151,7 +136,7 @@ QString PlatformXcb::platformName() const
 
 Platform::GrabModes PlatformXcb::supportedGrabModes() const
 {
-    Platform::GrabModes lSupportedModes({ GrabMode::AllScreens, GrabMode::ActiveWindow, GrabMode::WindowUnderCursor, GrabMode::TransientWithParent });
+    Platform::GrabModes lSupportedModes({ GrabMode::AllScreens, GrabMode::ActiveWindow, GrabMode::WindowUnderCursor, GrabMode::TransientWithParent, GrabMode::PerScreenImageNative });
     if (QApplication::screens().count() > 1) {
         lSupportedModes |= Platform::GrabMode::CurrentScreen;
     }
@@ -689,8 +674,22 @@ void PlatformXcb::doGrabNow(GrabMode theGrabMode, bool theIncludePointer, bool t
 {
     switch(theGrabMode) {
     case GrabMode::AllScreens:
+    case GrabMode::AllScreensScaled:
         grabAllScreens(theIncludePointer);
         break;
+    case GrabMode::PerScreenImageNative:{
+        auto lPixmap = getToplevelPixmap(QRect(), theIncludePointer);
+        // break thePixmap into list of images
+        const auto screens = QGuiApplication::screens();
+        QVector<QImage> images;
+        for (const auto screen: screens) {
+            QRect geom = screen->geometry();
+            geom.setSize(screen->size() * screen->devicePixelRatio());
+            images << lPixmap.copy(geom).toImage();
+        }
+        emit newScreensScreenshotTaken(images);
+        break;
+    }
     case GrabMode::CurrentScreen:
         grabCurrentScreen(theIncludePointer);
         break;
